@@ -2,11 +2,13 @@
 ///
 /// Adds additional math-related functionality to floats
 pub trait FloatExt {
-    /// Returns `0.0` if `self < edge` and 1.0 otherwise.
-    fn step(self, edge: Self) -> Self;
+    /// Returns `0.0` if `value < self` and 1.0 otherwise.
+    ///
+    /// Similar to glsl's step(edge, x), which translates into edge.step(x)
+    fn step(self, value: Self) -> Self;
 
-    /// Selects between `less` and `greater_or_equal` based on the result of `self < edge`
-    fn step_select(self, edge: Self, less: Self, greater_or_equal: Self) -> Self;
+    /// Selects between `less` and `greater_or_equal` based on the result of `value < self`
+    fn step_select(self, value: Self, less: Self, greater_or_equal: Self) -> Self;
 
     /// Performs a linear interpolation between `self` and `other` using `a` to weight between them.
     /// The return value is computed as `self * (1−a) + other * a`.
@@ -17,16 +19,16 @@ pub trait FloatExt {
 }
 
 impl FloatExt for f32 {
-    fn step(self, edge: Self) -> Self {
-        if self < edge {
+    fn step(self, value: Self) -> Self {
+        if value < self {
             0.0
         } else {
             1.0
         }
     }
 
-    fn step_select(self, edge: Self, less: Self, greater_or_equal: Self) -> Self {
-        if self < edge {
+    fn step_select(self, value: Self, less: Self, greater_or_equal: Self) -> Self {
+        if value < self {
             less
         } else {
             greater_or_equal
